diff --git a/Scripts/Functions/Help/help_updateOutputFilePdf.sh b/Scripts/Functions/Help/help_updateOutputFilePdf.sh
index 6a9898e..f0464ce 100755
--- a/Scripts/Functions/Help/help_updateOutputFilePdf.sh
+++ b/Scripts/Functions/Help/help_updateOutputFilePdf.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # texinfo_updateOutputFilePdf.sh -- This function exports documentation
 # manual to PDF format.
 #
 # Copyright (C) 2009, 2010, 2011 The CentOS Artwork SIG
@@ -23,7 +23,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function texinfo_updateOutputFilePdf {
+function help_updateOutputFilePdf {
 
     # Output action message.
     cli_printMessage "${MANUAL_BASEFILE}.pdf" --as-updating-line
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# texinfo_updateOutputFilePdf.sh -- This function exports documentation
+# help_updateOutputFilePdf.sh -- This function exports documentation
 # manual to PDF format.
 #